**Example 1: 删除一个模板实例**



Input: 

```
tccli tke DeletePrometheusTemplate --cli-unfold-argument  \
    --TemplateId temp-xxx
```

Output: 
```
{
    "Response": {
        "RequestId": "eac6b301-a322-493a-8e36-83b295459397"
    }
}
```

